<?php
/**
 * Judy Toma back compat functionality
 *
 * Prevents Judy Toma from running on WordPress versions prior to 3.6,
 * since this theme is not meant to be backward compatible and relies on
 * many new functions and markup changes introduced in 3.6.
 *
 * @package WordPress
 * @subpackage Twenty_Thirteen
 * @since Judy Toma 1.0
 */

/**
 * Prevent switching to Judy Toma on old versions of WordPress.
 *
 * Switches to the default theme.
 *
 * @since Judy Toma 1.0
 */
function judytoma_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'judytoma_upgrade_notice' );
}
add_action( 'after_switch_theme', 'judytoma_switch_theme' );

/**
 * Add message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * Judy Toma on WordPress versions prior to 3.6.
 *
 * @since Judy Toma 1.0
 */
function judytoma_upgrade_notice() {
	$message = sprintf( __( 'Judy Toma requires at least WordPress version 3.6. You are running version %s. Please upgrade and try again.', 'judytoma' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevent the Customizer from being loaded on WordPress versions prior to 3.6.
 *
 * @since Judy Toma 1.0
 */
function judytoma_customize() {
	wp_die( sprintf( __( 'Judy Toma requires at least WordPress version 3.6. You are running version %s. Please upgrade and try again.', 'judytoma' ), $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'judytoma_customize' );

/**
 * Prevent the Theme Preview from being loaded on WordPress versions prior to 3.4.
 *
 * @since Judy Toma 1.0
 */
function judytoma_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( __( 'Judy Toma requires at least WordPress version 3.6. You are running version %s. Please upgrade and try again.', 'judytoma' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'judytoma_preview' );
